@@ -2,30 +2,23 @@
 #' @family dwnld_read
 #' @param folder ruta temporal para descargar el archivo
 #' @importFrom readxl read_xls
-#' @importFrom dplyr slice mutate select everything
+#' @importFrom dplyr slice mutate select everything %>%
 #' @importFrom janitor clean_names excel_numeric_to_date
 #' @importFrom fs path
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
-#' @export
 #' @details
 #' Disclaimer: This script is not an official INE product.
 #' Aviso: El script no es un producto oficial de INE.
-#'
-#' @examples
-#' \donttest{
-#' get_ipc(folder = tempdir())
-#' }
 
 get_ipc <- function(folder = tempdir()){
 
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
-  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
+  assertthat::assert_that(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
 
   u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=2e92084a-94ec-4fec-b5ca-42b40d5d2826&groupId=10181"
   f <- fs::path(folder, "IPC gral var M_B10.xls")
   if (identical(.Platform$OS.type, "unix")) {
-    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget'))
   } else {
     try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
   }
@@ -76,24 +69,17 @@ dates_ech <- function(data) {
 #' @param sheet sheet number. Default 1.
 #'
 #' @importFrom readxl read_xls
-#' @importFrom dplyr slice mutate select everything filter_all slice any_vars bind_rows
+#' @importFrom dplyr slice mutate select everything filter_all slice any_vars bind_rows %>%
 #' @importFrom tidyr gather separate
 #' @importFrom janitor clean_names excel_numeric_to_date
 #' @importFrom fs path
-#' @importFrom magrittr %>%
 #' @return data.frame
-#' @export
 #' @details
 #' Disclaimer: This script is not an official INE product.
 #' Aviso: El script no es un producto oficial de INE.
-#'
-#' @examples
-#' \donttest{
-#' get_ipc_region(folder = tempdir(), region = "M")
-#' }
 
 get_ipc_region <- function(folder = tempdir(), region, sheet = 1){
-  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
+  assertthat::assert_that(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I"), msg = "Sorry... :( \n \t region parameter must be 'M' for Montevideo or 'I' for Interior")
 
@@ -106,7 +92,7 @@ get_ipc_region <- function(folder = tempdir(), region, sheet = 1){
     f <- fs::path(folder, "IPC 3.2 indvarinc_ div M_B10_Int.xls")
   }
   if (identical(.Platform$OS.type, "unix")) {
-    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget'))
   } else {
     try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
   }
@@ -139,29 +125,26 @@ get_ipc_region <- function(folder = tempdir(), region, sheet = 1){
 #' @param sheet sheet number. Default 1.
 #'
 #' @importFrom readxl read_xls
-#' @importFrom dplyr slice mutate bind_cols
+#' @importFrom dplyr slice mutate bind_cols %>%
 #' @importFrom janitor clean_names excel_numeric_to_date remove_empty
 #' @importFrom fs path
-#' @importFrom magrittr %>%
+#' @importFrom purrr map_df
+#' @importFrom curl has_internet
 #'
 #' @return data.frame
-#' @export
 #' @details
 #' Disclaimer: This script is not an official INE product.
 #' Aviso: El script no es un producto oficial de INE.
-#'
-#' @examples
-#' get_cba_cbna(folder = tempdir(), region = "M")
-#'
+
 get_cba_cbna <- function(folder = tempdir(), region, sheet = 1){
-  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
+  assertthat::assert_that(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg =  "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I", "R"), msg =  "Sorry... :( \n \t region parameter must be 'M' for Montevideo, 'I' for Interior urbano or 'R' for Interior rural")
 
   u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=1675e7d0-6fe0-49bd-bf3f-a46bd6334c0c&groupId=10181"
   f <- fs::path(folder, "CBA_LP_LI_M.xls")
   if (identical(.Platform$OS.type, "unix")) {
-    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget'))
   } else {
     try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
   }
@@ -211,23 +194,21 @@ get_cba_cbna <- function(folder = tempdir(), region, sheet = 1){
 #' @importFrom janitor remove_empty
 #' @importFrom dplyr bind_rows slice filter_all bind_cols any_vars mutate_all
 #' @importFrom tidyr fill
+#' @importFrom curl has_internet
+#'
 #' @return data.frame
-#' @export
 #' @details
 #' Disclaimer: This script is not an official INE product.
 #' Aviso: El script no es un producto oficial de INE.
-#'
-#' @examples
-#' get_ipab(folder = tempdir())
 
 get_ipab <- function(folder = tempdir(), sheet = 1){
-  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
+  assertthat::assert_that(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg =  "Sorry... :( \n \t folder parameter must be character")
 
   u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=c4b5efaa-cdd4-497a-ab78-e3138e4f08dc&groupId=10181"
   f <- fs::path(folder, "IPC Div M_B10.xls")
   if (identical(.Platform$OS.type, "unix")) {
-    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget'))
   } else {
     try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
   }
@@ -257,13 +238,9 @@ get_ipab <- function(folder = tempdir(), sheet = 1){
 #' @importFrom dplyr bind_rows slice filter_all bind_cols any_vars mutate
 #' @importFrom tidyr drop_na separate
 #' @return data.frame
-#' @export
-#'
-#' @examples
-#' get_ipab_region(folder = tempdir(), region = "M")
-#'
+
 get_ipab_region <- function(folder = tempdir(), region, sheet = 1){
-  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
+  assertthat::assert_that(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I"), msg = "Sorry... :( \n \t region parameter must be 'M' for Montevideo or 'I' for Interior")
 
@@ -275,7 +252,7 @@ get_ipab_region <- function(folder = tempdir(), region, sheet = 1){
     f <- fs::path(folder, "IPC 3.2 indvarinc_ div M_B10_Int.xls")
   }
   if (identical(.Platform$OS.type, "unix")) {
-    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget'))
   } else {
     try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
   }
@@ -304,40 +281,6 @@ get_ipab_region <- function(folder = tempdir(), region, sheet = 1){
   })
 }
 
-#' This function allows you to get the CIIU data
-#' @family dwnld_read
-#' @param folder temp folder
-#' @param version by default the last ciiu version
-#' @importFrom utils read.csv
-#' @importFrom pdftables convert_pdf
-#' @importFrom rstudioapi askForSecret
-#' @export
-#' @details
-#' Disclaimer: This script is not an official INE product.
-#' Aviso: El script no es un producto oficial de INE.
-
-get_ciiu <- function(folder = tempdir(),
-                     version = 4){
-  assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
-  assertthat::assert_that(is.numeric(version), msg = "Sorry... :( \n \t version parameter must be numeric")
-  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
-  u <- "http://www.ine.gub.uy/documents/10181/33330/CORRESPONDENCIA+CIUU4+A+CIUU3.pdf/623c43cb-009c-4da9-b48b-45282745063b"
-  f <- fs::path(folder, "ciiu4.pdf")
-  if (identical(.Platform$OS.type, "unix")) {
-    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
-  } else {
-    try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
-  }
-  key <- rstudioapi::askForSecret("api_key")
-  pdftables::convert_pdf(f, "ciiu4.csv",api_key = key)
-  df <- read.csv("ciiu4.csv")
-  df <- df[,-3]
-  names(df) <- c("ciiu_4","description", "ciiu_3")
-  df <- df[-1,]
-  df[] <- lapply(df, textclean::replace_non_ascii)
-  ciiu4 <- df
-}
-
 #' This function allows you to calculate a deflator coefficient
 #' @family income
 #' @param base_month baseline month
@@ -347,14 +290,9 @@ get_ciiu <- function(folder = tempdir(),
 #' @param df_year ECH year
 #' @importFrom dplyr select slice mutate
 #' @importFrom rlang .data
-#' @export
 #' @details
 #' Disclaimer: This script is not an official INE product.
 #' Aviso: El script no es un producto oficial de INE.
-#' @examples
-#' \donttest{
-#' deflate(base_month = 6, base_year = 2016, index = "IPC", level = "G", df_year = 2018)
-#' }
 
 deflate <- function(base_month = NULL,
                     base_year = NULL,
@@ -510,13 +448,48 @@ organize_ht11 <- function(data, year, ht11 = "ht11", numero = "numero") {
   return(data)
 }
 
+# #' This function allows you to get the CIIU data
+# #' @family dwnld_read
+# #' @param folder temp folder
+# #' @param version by default the last ciiu version
+# #' @importFrom utils read.csv
+# #' @importFrom pdftables convert_pdf
+# #' @importFrom rstudioapi askForSecret
+# #' @export
+# #' @details
+# #' Disclaimer: This script is not an official INE product.
+# #' Aviso: El script no es un producto oficial de INE.
+#
+# get_ciiu <- function(folder = tempdir(),
+#                      version = 4){
+#   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
+#   assertthat::assert_that(is.numeric(version), msg = "Sorry... :( \n \t version parameter must be numeric")
+#   assertthat::assert_that(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
+#   u <- "http://www.ine.gub.uy/documents/10181/33330/CORRESPONDENCIA+CIUU4+A+CIUU3.pdf/623c43cb-009c-4da9-b48b-45282745063b"
+#   f <- fs::path(folder, "ciiu4.pdf")
+#   if (identical(.Platform$OS.type, "unix")) {
+#     try(utils::download.file(u, f, mode = 'wb', method = 'wget'))
+#   } else {
+#     try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
+#   }
+#   key <- rstudioapi::askForSecret("api_key")
+#   pdftables::convert_pdf(f, "ciiu4.csv",api_key = key)
+#   df <- read.csv("ciiu4.csv")
+#   df <- df[,-3]
+#   names(df) <- c("ciiu_4","description", "ciiu_3")
+#   df <- df[-1,]
+#   df[] <- lapply(df, textclean::replace_non_ascii)
+#   ciiu4 <- df
+# }
+
+
 #' Pipe operator
-#' See \code{magrittr::\link[magrittr]{\%>\%}} for details.
+#' See \code{dplyr::\link[dplyr]{\%>\%}} for details.
 #' @name %>%
 #' @rdname pipe
 #' @keywords internal
 #' @export
-#' @importFrom magrittr %>%
+#' @importFrom dplyr %>%
 #' @usage lhs \%>\% rhs
 NULL
 
